/* properties.c generated by valac 0.22.1.2-49127, the Vala compiler
 * generated from properties.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <clutter/clutter.h>
#include <gtk/gtk.h>
#include <clutter-gtk/clutter-gtk.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <pango/pango.h>
#include <glib/gi18n-lib.h>
#include <float.h>
#include <math.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>


#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;
typedef struct _BoxesPropertiesPrivate BoxesPropertiesPrivate;

#define BOXES_TYPE_MINI_GRAPH (boxes_mini_graph_get_type ())
#define BOXES_MINI_GRAPH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraph))
#define BOXES_MINI_GRAPH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraphClass))
#define BOXES_IS_MINI_GRAPH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MINI_GRAPH))
#define BOXES_IS_MINI_GRAPH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MINI_GRAPH))
#define BOXES_MINI_GRAPH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraphClass))

typedef struct _BoxesMiniGraph BoxesMiniGraph;
typedef struct _BoxesMiniGraphClass BoxesMiniGraphClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;

#define BOXES_PROPERTIES_TYPE_PAGE_WIDGET (boxes_properties_page_widget_get_type ())
#define BOXES_PROPERTIES_PAGE_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_PROPERTIES_TYPE_PAGE_WIDGET, BoxesPropertiesPageWidget))
#define BOXES_PROPERTIES_PAGE_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_PROPERTIES_TYPE_PAGE_WIDGET, BoxesPropertiesPageWidgetClass))
#define BOXES_PROPERTIES_IS_PAGE_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_PROPERTIES_TYPE_PAGE_WIDGET))
#define BOXES_PROPERTIES_IS_PAGE_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_PROPERTIES_TYPE_PAGE_WIDGET))
#define BOXES_PROPERTIES_PAGE_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_PROPERTIES_TYPE_PAGE_WIDGET, BoxesPropertiesPageWidgetClass))

typedef struct _BoxesPropertiesPageWidget BoxesPropertiesPageWidget;
typedef struct _BoxesPropertiesPageWidgetClass BoxesPropertiesPageWidgetClass;
typedef struct _BoxesPropertiesPageWidgetPrivate BoxesPropertiesPageWidgetPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _gtk_tree_path_free0(var) ((var == NULL) ? NULL : (var = (gtk_tree_path_free (var), NULL)))

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesTopbarPrivate BoxesTopbarPrivate;

#define BOXES_TYPE_TOPBAR_PAGE (boxes_topbar_page_get_type ())
typedef struct _BoxesSidebarPrivate BoxesSidebarPrivate;

#define BOXES_TYPE_SIDEBAR_PAGE (boxes_sidebar_page_get_type ())
typedef struct _Block50Data Block50Data;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
typedef struct _BoxesLibvirtMachinePrivate BoxesLibvirtMachinePrivate;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesProperties {
	BoxesUI parent_instance;
	BoxesPropertiesPrivate * priv;
	GtkWidget* screenshot_placeholder;
};

struct _BoxesPropertiesClass {
	BoxesUIClass parent_class;
};

struct _BoxesPropertiesPrivate {
	GtkClutterActor* gtk_actor;
	GtkNotebook* notebook;
	GtkButton* back;
	GtkHeaderBar* toolbar;
	GtkListStore* listmodel;
	GtkTreeModelFilter* model_filter;
	GtkTreeView* tree_view;
	GtkButton* shutdown_button;
	GBinding* toolbar_label_bind;
	BoxesMiniGraph* cpu;
	BoxesMiniGraph* io;
	BoxesMiniGraph* net;
	gulong stats_id;
	gboolean restore_fullscreen;
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* searchbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

struct _BoxesPropertiesPageWidget {
	GObject parent_instance;
	BoxesPropertiesPageWidgetPrivate * priv;
	GtkWidget* widget;
	gchar* name;
	gboolean empty;
};

struct _BoxesPropertiesPageWidgetClass {
	GObjectClass parent_class;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesTopbar {
	BoxesUI parent_instance;
	BoxesTopbarPrivate * priv;
	GtkNotebook* notebook;
	gchar* _status;
};

struct _BoxesTopbarClass {
	BoxesUIClass parent_class;
};

typedef enum  {
	BOXES_TOPBAR_PAGE_COLLECTION,
	BOXES_TOPBAR_PAGE_SELECTION,
	BOXES_TOPBAR_PAGE_WIZARD,
	BOXES_TOPBAR_PAGE_PROPERTIES,
	BOXES_TOPBAR_PAGE_DISPLAY
} BoxesTopbarPage;

struct _BoxesSidebar {
	BoxesUI parent_instance;
	BoxesSidebarPrivate * priv;
	GtkNotebook* notebook;
};

struct _BoxesSidebarClass {
	BoxesUIClass parent_class;
};

typedef enum  {
	BOXES_SIDEBAR_PAGE_COLLECTION,
	BOXES_SIDEBAR_PAGE_WIZARD,
	BOXES_SIDEBAR_PAGE_PROPERTIES
} BoxesSidebarPage;

struct _Block50Data {
	int _ref_count_;
	BoxesProperties * self;
	BoxesLibvirtMachine* libvirt_machine;
};

struct _BoxesCollectionItem {
	BoxesUI parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	BoxesUIClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

struct _BoxesLibvirtMachine {
	BoxesMachine parent_instance;
	BoxesLibvirtMachinePrivate * priv;
	gdouble* cpu_stats;
	gint cpu_stats_length1;
	gint _cpu_stats_size_;
	gdouble* io_stats;
	gint io_stats_length1;
	gint _io_stats_size_;
	gdouble* net_stats;
	gint net_stats_length1;
	gint _net_stats_size_;
};

struct _BoxesLibvirtMachineClass {
	BoxesMachineClass parent_class;
};

struct _BoxesPropertiesPageWidgetPrivate {
	GtkGrid* grid;
	GtkInfoBar* infobar;
	GList* properties;
};


static gpointer boxes_properties_parent_class = NULL;
extern BoxesApp* boxes_app_app;
static gpointer boxes_properties_page_widget_parent_class = NULL;

GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_mini_graph_get_type (void) G_GNUC_CONST;
#define BOXES_PROPERTIES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_PROPERTIES, BoxesPropertiesPrivate))
enum  {
	BOXES_PROPERTIES_DUMMY_PROPERTY,
	BOXES_PROPERTIES_ACTOR,
	BOXES_PROPERTIES_TITLE
};
BoxesProperties* boxes_properties_new (void);
BoxesProperties* boxes_properties_construct (GType object_type);
BoxesUI* boxes_ui_construct (GType object_type);
static void boxes_properties_setup_ui (BoxesProperties* self);
static void boxes_properties_list_append (BoxesProperties* self, GtkListStore* listmodel, const gchar* label, gboolean visible);
static void boxes_properties_populate (BoxesProperties* self);
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
gboolean boxes_machine_is_running (BoxesMachine* self);
static GType boxes_properties_page_widget_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static BoxesPropertiesPageWidget* boxes_properties_page_widget_new (BoxesPropertiesPage page, BoxesMachine* machine);
static BoxesPropertiesPageWidget* boxes_properties_page_widget_construct (GType object_type, BoxesPropertiesPage page, BoxesMachine* machine);
static void _____lambda156_ (BoxesProperties* self);
static void ______lambda156__boxes_properties_page_widget_refresh_properties (BoxesPropertiesPageWidget* _sender, gpointer self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
GType boxes_topbar_page_get_type (void) G_GNUC_CONST;
static void __lambda150_ (BoxesProperties* self, GtkButton* button);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void ___lambda150__gtk_button_clicked (GtkButton* _sender, gpointer self);
GType boxes_sidebar_page_get_type (void) G_GNUC_CONST;
void boxes_tree_view_activate_on_single_click (GtkTreeView* tree_view, gboolean should_activate);
static void __lambda153_ (BoxesProperties* self, GtkTreeView* treeview, GtkTreePath* path, GtkTreeViewColumn* column);
static void ___lambda153__gtk_tree_view_row_activated (GtkTreeView* _sender, GtkTreePath* path, GtkTreeViewColumn* column, gpointer self);
#define BOXES_SIDEBAR_shadow_width 7
BoxesMiniGraph* boxes_mini_graph_new_with_ymax (gdouble* points, int points_length1, gdouble ymax, gint npoints);
BoxesMiniGraph* boxes_mini_graph_construct_with_ymax (GType object_type, gdouble* points, int points_length1, gdouble ymax, gint npoints);
BoxesMiniGraph* boxes_mini_graph_new (gdouble* points, int points_length1, gint npoints);
BoxesMiniGraph* boxes_mini_graph_construct (GType object_type, gdouble* points, int points_length1, gint npoints);
static void __lambda154_ (BoxesProperties* self);
void boxes_libvirt_machine_force_shutdown (BoxesLibvirtMachine* self, gboolean confirm);
static void ___lambda154__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_properties_real_ui_state_changed (BoxesUI* base);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
gboolean boxes_app_get_fullscreen (BoxesApp* self);
void boxes_app_set_fullscreen (BoxesApp* self, gboolean value);
static Block50Data* block50_data_ref (Block50Data* _data50_);
static void block50_data_unref (void * _userdata_);
static void ____lambda157_ (Block50Data* _data50_);
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
void boxes_mini_graph_set_points (BoxesMiniGraph* self, gdouble* value, int value_length1);
static void _____lambda157__boxes_libvirt_machine_stats_updated (BoxesLibvirtMachine* _sender, gpointer self);
static void boxes_properties_page_widget_flush_changes (BoxesPropertiesPageWidget* self);
void boxes_fade_actor (ClutterActor* actor, guint opacity);
ClutterActor* boxes_ui_get_actor (BoxesUI* self);
void boxes_properties_set_title (BoxesProperties* self, const gchar* value);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
#define BOXES_PROPERTIES_PAGE_WIDGET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_PROPERTIES_TYPE_PAGE_WIDGET, BoxesPropertiesPageWidgetPrivate))
enum  {
	BOXES_PROPERTIES_PAGE_WIDGET_DUMMY_PROPERTY
};
static void boxes_properties_page_widget_update_infobar (BoxesPropertiesPageWidget* self);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
gboolean boxes_property_get_reboot_required (BoxesProperty* self);
GList* boxes_machine_get_properties (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
const gchar* boxes_property_get_description (BoxesProperty* self);
GtkWidget* boxes_property_get_widget (BoxesProperty* self);
GtkWidget* boxes_property_get_extra_widget (BoxesProperty* self);
static void _boxes_properties_page_widget_update_infobar_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _____lambda155_ (BoxesPropertiesPageWidget* self);
static void ______lambda155__boxes_property_refresh_properties (BoxesProperty* _sender, gpointer self);
void boxes_property_flush (BoxesProperty* self);
static void boxes_properties_page_widget_finalize (GObject* obj);
static void boxes_properties_finalize (GObject* obj);
static void _vala_boxes_properties_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_properties_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


GType boxes_properties_page_get_type (void) {
	static volatile gsize boxes_properties_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_properties_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_PROPERTIES_PAGE_LOGIN, "BOXES_PROPERTIES_PAGE_LOGIN", "login"}, {BOXES_PROPERTIES_PAGE_SYSTEM, "BOXES_PROPERTIES_PAGE_SYSTEM", "system"}, {BOXES_PROPERTIES_PAGE_DISPLAY, "BOXES_PROPERTIES_PAGE_DISPLAY", "display"}, {BOXES_PROPERTIES_PAGE_DEVICES, "BOXES_PROPERTIES_PAGE_DEVICES", "devices"}, {BOXES_PROPERTIES_PAGE_LAST, "BOXES_PROPERTIES_PAGE_LAST", "last"}, {0, NULL, NULL}};
		GType boxes_properties_page_type_id;
		boxes_properties_page_type_id = g_enum_register_static ("BoxesPropertiesPage", values);
		g_once_init_leave (&boxes_properties_page_type_id__volatile, boxes_properties_page_type_id);
	}
	return boxes_properties_page_type_id__volatile;
}


BoxesProperties* boxes_properties_construct (GType object_type) {
	BoxesProperties * self = NULL;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesProperties*) boxes_ui_construct (object_type);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_properties_setup_ui (self);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return self;
#line 613 "properties.c"
}


BoxesProperties* boxes_properties_new (void) {
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return boxes_properties_construct (BOXES_TYPE_PROPERTIES);
#line 620 "properties.c"
}


static void boxes_properties_list_append (BoxesProperties* self, GtkListStore* listmodel, const gchar* label, gboolean visible) {
	GtkTreeIter iter = {0};
	GtkListStore* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	GtkListStore* _tmp2_ = NULL;
	GtkTreeIter _tmp3_ = {0};
	const gchar* _tmp4_ = NULL;
	GtkListStore* _tmp5_ = NULL;
	GtkTreeIter _tmp6_ = {0};
	gboolean _tmp7_ = FALSE;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (self != NULL);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (listmodel != NULL);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (label != NULL);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = listmodel;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_list_store_append (_tmp0_, &_tmp1_);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	iter = _tmp1_;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp2_ = listmodel;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp3_ = iter;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp4_ = label;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_list_store_set (_tmp2_, &_tmp3_, 0, _tmp4_, -1);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5_ = listmodel;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp6_ = iter;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp7_ = visible;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_list_store_set (_tmp5_, &_tmp6_, 1, _tmp7_, -1);
#line 662 "properties.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return self ? g_object_ref (self) : NULL;
#line 669 "properties.c"
}


static void _____lambda156_ (BoxesProperties* self) {
	gint current_page = 0;
	GtkNotebook* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	GtkTreePath* path = NULL;
	GtkTreePath* _tmp3_ = NULL;
	GtkTreeView* _tmp4_ = NULL;
	GtkTreeSelection* _tmp5_ = NULL;
	GtkNotebook* _tmp6_ = NULL;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->notebook;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_get (_tmp0_, "page", &_tmp1_, NULL);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp2_ = _tmp1_;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	current_page = _tmp2_;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_properties_populate (self);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp3_ = gtk_tree_path_new_from_indices (current_page, -1);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	path = _tmp3_;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp4_ = self->priv->tree_view;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5_ = gtk_tree_view_get_selection (_tmp4_);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_tree_selection_select_path (_tmp5_, path);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp6_ = self->priv->notebook;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_set (_tmp6_, "page", current_page, NULL);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_gtk_tree_path_free0 (path);
#line 709 "properties.c"
}


static void ______lambda156__boxes_properties_page_widget_refresh_properties (BoxesPropertiesPageWidget* _sender, gpointer self) {
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_____lambda156_ (self);
#line 716 "properties.c"
}


static void boxes_properties_populate (BoxesProperties* self) {
	GtkListStore* _tmp0_ = NULL;
	BoxesMachine* machine = NULL;
	BoxesApp* _tmp6_ = NULL;
	BoxesCollectionItem* _tmp7_ = NULL;
	BoxesMachine* _tmp8_ = NULL;
	BoxesLibvirtMachine* libvirt_machine = NULL;
	BoxesApp* _tmp9_ = NULL;
	BoxesCollectionItem* _tmp10_ = NULL;
	BoxesLibvirtMachine* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	BoxesLibvirtMachine* _tmp13_ = NULL;
	GtkButton* _tmp16_ = NULL;
	gboolean _tmp17_ = FALSE;
	BoxesMachine* _tmp18_ = NULL;
	BoxesPropertiesPage current_page = 0;
	BoxesLibvirtMachine* _tmp43_ = NULL;
	GtkTreePath* path = NULL;
	BoxesPropertiesPage _tmp48_ = 0;
	GtkTreePath* _tmp49_ = NULL;
	GtkTreeView* _tmp50_ = NULL;
	GtkTreeSelection* _tmp51_ = NULL;
	GtkTreePath* _tmp52_ = NULL;
	GtkNotebook* _tmp53_ = NULL;
	BoxesPropertiesPage _tmp54_ = 0;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (self != NULL);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->listmodel;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_list_store_clear (_tmp0_);
#line 751 "properties.c"
	{
		gint i = 0;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		i = 0;
#line 756 "properties.c"
		{
			gboolean _tmp1_ = FALSE;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp1_ = TRUE;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			while (TRUE) {
#line 763 "properties.c"
				gboolean _tmp2_ = FALSE;
				gint _tmp4_ = 0;
				GtkNotebook* _tmp5_ = NULL;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp2_ = _tmp1_;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				if (!_tmp2_) {
#line 771 "properties.c"
					gint _tmp3_ = 0;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp3_ = i;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					i = _tmp3_ + 1;
#line 777 "properties.c"
				}
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp1_ = FALSE;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp4_ = i;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				if (!(_tmp4_ < ((gint) BOXES_PROPERTIES_PAGE_LAST))) {
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					break;
#line 787 "properties.c"
				}
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp5_ = self->priv->notebook;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				gtk_notebook_remove_page (_tmp5_, -1);
#line 793 "properties.c"
			}
		}
	}
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp6_ = boxes_app_app;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp7_ = _tmp6_->current_item;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp7_) : NULL);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	machine = _tmp8_;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp9_ = boxes_app_app;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp10_ = _tmp9_->current_item;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp11_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp10_) : NULL);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	libvirt_machine = _tmp11_;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp13_ = libvirt_machine;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp13_ != NULL) {
#line 817 "properties.c"
		BoxesLibvirtMachine* _tmp14_ = NULL;
		gboolean _tmp15_ = FALSE;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp14_ = libvirt_machine;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp15_ = boxes_machine_is_running ((BoxesMachine*) _tmp14_);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp12_ = _tmp15_;
#line 826 "properties.c"
	} else {
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp12_ = FALSE;
#line 830 "properties.c"
	}
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp16_ = self->priv->shutdown_button;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp17_ = _tmp12_;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp16_, _tmp17_);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp18_ = machine;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp18_ == NULL) {
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (libvirt_machine);
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (machine);
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		return;
#line 848 "properties.c"
	}
	{
		gint i = 0;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		i = 0;
#line 854 "properties.c"
		{
			gboolean _tmp19_ = FALSE;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp19_ = TRUE;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			while (TRUE) {
#line 861 "properties.c"
				gboolean _tmp20_ = FALSE;
				gint _tmp22_ = 0;
				BoxesPropertiesPageWidget* page = NULL;
				gint _tmp23_ = 0;
				BoxesMachine* _tmp24_ = NULL;
				BoxesPropertiesPageWidget* _tmp25_ = NULL;
				GtkNotebook* _tmp26_ = NULL;
				BoxesPropertiesPageWidget* _tmp27_ = NULL;
				GtkWidget* _tmp28_ = NULL;
				GtkNotebook* _tmp29_ = NULL;
				gint _tmp30_ = 0;
				gchar* _tmp31_ = NULL;
				gchar* _tmp32_ = NULL;
				gchar* _tmp33_ = NULL;
				gchar* _tmp34_ = NULL;
				BoxesPropertiesPageWidget* _tmp35_ = NULL;
				BoxesPropertiesPageWidget* _tmp36_ = NULL;
				BoxesPropertiesPageWidget* _tmp37_ = NULL;
				GtkListStore* _tmp38_ = NULL;
				BoxesPropertiesPageWidget* _tmp39_ = NULL;
				const gchar* _tmp40_ = NULL;
				BoxesPropertiesPageWidget* _tmp41_ = NULL;
				gboolean _tmp42_ = FALSE;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp20_ = _tmp19_;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				if (!_tmp20_) {
#line 889 "properties.c"
					gint _tmp21_ = 0;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp21_ = i;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					i = _tmp21_ + 1;
#line 895 "properties.c"
				}
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp19_ = FALSE;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp22_ = i;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				if (!(_tmp22_ < ((gint) BOXES_PROPERTIES_PAGE_LAST))) {
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					break;
#line 905 "properties.c"
				}
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp23_ = i;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp24_ = machine;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp25_ = boxes_properties_page_widget_new (_tmp23_, _tmp24_);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				page = _tmp25_;
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp26_ = self->priv->notebook;
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp27_ = page;
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp28_ = _tmp27_->widget;
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				gtk_notebook_append_page (_tmp26_, _tmp28_, NULL);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp29_ = self->priv->notebook;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp30_ = i;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp31_ = g_strdup_printf ("%i", _tmp30_);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp32_ = _tmp31_;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp33_ = g_strconcat ("boxes-property-", _tmp32_, NULL);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp34_ = _tmp33_;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp35_ = page;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp36_ = _g_object_ref0 (_tmp35_);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				g_object_set_data_full ((GObject*) _tmp29_, _tmp34_, _tmp36_, g_object_unref);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_free0 (_tmp34_);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_free0 (_tmp32_);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp37_ = page;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				g_signal_connect_object (_tmp37_, "refresh-properties", (GCallback) ______lambda156__boxes_properties_page_widget_refresh_properties, self, 0);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp38_ = self->priv->listmodel;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp39_ = page;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp40_ = _tmp39_->name;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp41_ = page;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp42_ = _tmp41_->empty;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				boxes_properties_list_append (self, _tmp38_, _tmp40_, !_tmp42_);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_object_unref0 (page);
#line 963 "properties.c"
			}
		}
	}
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp43_ = libvirt_machine;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp43_ != NULL) {
#line 971 "properties.c"
		BoxesPropertiesPage _tmp44_ = 0;
		BoxesUIState _tmp45_ = 0;
		BoxesUIState _tmp46_ = 0;
		BoxesPropertiesPage _tmp47_ = 0;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp45_ = boxes_ui_get_previous_ui_state ((BoxesUI*) self);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp46_ = _tmp45_;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		if (_tmp46_ == BOXES_UI_STATE_WIZARD) {
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp44_ = BOXES_PROPERTIES_PAGE_SYSTEM;
#line 984 "properties.c"
		} else {
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp44_ = BOXES_PROPERTIES_PAGE_LOGIN;
#line 988 "properties.c"
		}
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp47_ = _tmp44_;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		current_page = _tmp47_;
#line 994 "properties.c"
	} else {
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		current_page = BOXES_PROPERTIES_PAGE_LOGIN;
#line 998 "properties.c"
	}
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp48_ = current_page;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp49_ = gtk_tree_path_new_from_indices (_tmp48_, -1);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	path = _tmp49_;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp50_ = self->priv->tree_view;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp51_ = gtk_tree_view_get_selection (_tmp50_);
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp52_ = path;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_tree_selection_select_path (_tmp51_, _tmp52_);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp53_ = self->priv->notebook;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp54_ = current_page;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_notebook_set_current_page (_tmp53_, (gint) _tmp54_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_gtk_tree_path_free0 (path);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (libvirt_machine);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (machine);
#line 1026 "properties.c"
}


static void __lambda150_ (BoxesProperties* self, GtkButton* button) {
	BoxesApp* _tmp0_ = NULL;
	BoxesApp* _tmp1_ = NULL;
	BoxesUIState _tmp2_ = 0;
	BoxesUIState _tmp3_ = 0;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (button != NULL);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = boxes_app_app;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp1_ = boxes_app_app;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp2_ = boxes_ui_get_previous_ui_state ((BoxesUI*) _tmp1_);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp3_ = _tmp2_;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_ui_set_ui_state ((BoxesUI*) _tmp0_, _tmp3_);
#line 1047 "properties.c"
}


static void ___lambda150__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	__lambda150_ (self, _sender);
#line 1054 "properties.c"
}


static void __lambda153_ (BoxesProperties* self, GtkTreeView* treeview, GtkTreePath* path, GtkTreeViewColumn* column) {
	GtkTreeIter filter_iter = {0};
	GtkTreeIter iter = {0};
	GtkTreeModelFilter* _tmp0_ = NULL;
	GtkTreePath* _tmp1_ = NULL;
	GtkTreeIter _tmp2_ = {0};
	GtkTreeModelFilter* _tmp3_ = NULL;
	GtkTreeIter _tmp4_ = {0};
	GtkTreeIter _tmp5_ = {0};
	GtkNotebook* _tmp6_ = NULL;
	GtkListStore* _tmp7_ = NULL;
	GtkTreeIter _tmp8_ = {0};
	GtkTreePath* _tmp9_ = NULL;
	GtkTreePath* _tmp10_ = NULL;
	gint _tmp11_ = 0;
	gint* _tmp12_ = NULL;
	gint _tmp13_ = 0;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (treeview != NULL);
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (path != NULL);
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (column != NULL);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->model_filter;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp1_ = path;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_tree_model_get_iter ((GtkTreeModel*) _tmp0_, &_tmp2_, _tmp1_);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	filter_iter = _tmp2_;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp3_ = self->priv->model_filter;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp4_ = filter_iter;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_tree_model_filter_convert_iter_to_child_iter (_tmp3_, &_tmp5_, &_tmp4_);
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	iter = _tmp5_;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp6_ = self->priv->notebook;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp7_ = self->priv->listmodel;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp8_ = iter;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp9_ = gtk_tree_model_get_path ((GtkTreeModel*) _tmp7_, &_tmp8_);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp10_ = _tmp9_;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp12_ = gtk_tree_path_get_indices_with_depth (_tmp10_, &_tmp11_);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp13_ = _tmp12_[0];
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_set (_tmp6_, "page", _tmp13_, NULL);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_gtk_tree_path_free0 (_tmp10_);
#line 1115 "properties.c"
}


static void ___lambda153__gtk_tree_view_row_activated (GtkTreeView* _sender, GtkTreePath* path, GtkTreeViewColumn* column, gpointer self) {
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	__lambda153_ (self, _sender, path, column);
#line 1122 "properties.c"
}


static void __lambda154_ (BoxesProperties* self) {
	BoxesLibvirtMachine* machine = NULL;
	BoxesApp* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
	BoxesLibvirtMachine* _tmp3_ = NULL;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = boxes_app_app;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp1_ = _tmp0_->current_item;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp1_) : NULL);
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	machine = _tmp2_;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp3_ = machine;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp3_ != NULL) {
#line 1144 "properties.c"
		BoxesLibvirtMachine* _tmp4_ = NULL;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp4_ = machine;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		boxes_libvirt_machine_force_shutdown (_tmp4_, TRUE);
#line 1150 "properties.c"
	}
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (machine);
#line 1154 "properties.c"
}


static void ___lambda154__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	__lambda154_ (self);
#line 1161 "properties.c"
}


static void boxes_properties_setup_ui (BoxesProperties* self) {
	GtkNotebook* _tmp0_ = NULL;
	GtkNotebook* _tmp1_ = NULL;
	GtkNotebook* _tmp2_ = NULL;
	GtkStyleContext* _tmp3_ = NULL;
	GtkNotebook* _tmp4_ = NULL;
	GtkClutterActor* _tmp5_ = NULL;
	GtkClutterActor* _tmp6_ = NULL;
	GtkWidget* _tmp7_ = NULL;
	GtkStyleContext* _tmp8_ = NULL;
	GtkClutterActor* _tmp9_ = NULL;
	GtkClutterActor* _tmp10_ = NULL;
	GtkClutterActor* _tmp11_ = NULL;
	GtkClutterActor* _tmp12_ = NULL;
	GtkClutterActor* _tmp13_ = NULL;
	GtkClutterActor* _tmp14_ = NULL;
	GtkBox* hbox = NULL;
	BoxesApp* _tmp15_ = NULL;
	BoxesTopbar* _tmp16_ = NULL;
	GtkNotebook* _tmp17_ = NULL;
	GtkWidget* _tmp18_ = NULL;
	GtkBox* _tmp19_ = NULL;
	GtkHeaderBar* _tmp20_ = NULL;
	GtkHeaderBar* _tmp21_ = NULL;
	GtkStyleContext* _tmp22_ = NULL;
	GtkHeaderBar* _tmp23_ = NULL;
	GtkStyleContext* _tmp24_ = NULL;
	GtkHeaderBar* _tmp25_ = NULL;
	GtkBox* _tmp26_ = NULL;
	GtkHeaderBar* _tmp27_ = NULL;
	const gchar* _tmp28_ = NULL;
	GtkHeaderBar* _tmp29_ = NULL;
	GtkTextDirection _tmp30_ = 0;
	gchar* back_icon = NULL;
	const gchar* _tmp31_ = NULL;
	gchar* _tmp32_ = NULL;
	GtkImage* back_image = NULL;
	GtkImage* _tmp33_ = NULL;
	GtkButton* _tmp34_ = NULL;
	GtkButton* _tmp35_ = NULL;
	GtkButton* _tmp36_ = NULL;
	GtkButton* _tmp37_ = NULL;
	GtkStyleContext* _tmp38_ = NULL;
	GtkHeaderBar* _tmp39_ = NULL;
	GtkButton* _tmp40_ = NULL;
	GtkButton* _tmp41_ = NULL;
	GtkBox* _tmp42_ = NULL;
	GtkBox* vbox = NULL;
	BoxesApp* _tmp43_ = NULL;
	BoxesSidebar* _tmp44_ = NULL;
	GtkNotebook* _tmp45_ = NULL;
	GtkWidget* _tmp46_ = NULL;
	GtkBox* _tmp47_ = NULL;
	GtkTreeView* _tmp48_ = NULL;
	GtkTreeView* _tmp49_ = NULL;
	GtkStyleContext* _tmp50_ = NULL;
	GtkTreeSelection* selection = NULL;
	GtkTreeView* _tmp51_ = NULL;
	GtkTreeSelection* _tmp52_ = NULL;
	GtkTreeSelection* _tmp53_ = NULL;
	GtkTreeView* _tmp54_ = NULL;
	GtkTreeView* _tmp55_ = NULL;
	GtkListStore* _tmp56_ = NULL;
	GtkListStore* _tmp57_ = NULL;
	GtkTreeModelFilter* _tmp58_ = NULL;
	GtkTreeModelFilter* _tmp59_ = NULL;
	GtkTreeView* _tmp60_ = NULL;
	GtkTreeModelFilter* _tmp61_ = NULL;
	GtkTreeView* _tmp62_ = NULL;
	GtkCellRendererText* renderer = NULL;
	GtkCellRendererText* _tmp63_ = NULL;
	GtkTreeView* _tmp64_ = NULL;
	GtkTreeView* _tmp65_ = NULL;
	GtkGrid* grid = NULL;
	GtkGrid* _tmp66_ = NULL;
	GtkAlignment* _tmp67_ = NULL;
	GtkWidget* _tmp68_ = NULL;
	GtkWidget* _tmp69_ = NULL;
	GtkLabel* label = NULL;
	const gchar* _tmp70_ = NULL;
	GtkLabel* _tmp71_ = NULL;
	GtkLabel* _tmp72_ = NULL;
	GtkStyleContext* _tmp73_ = NULL;
	GtkLabel* _tmp74_ = NULL;
	gdouble* _tmp75_ = NULL;
	gdouble* _tmp76_ = NULL;
	gint _tmp76__length1 = 0;
	BoxesMiniGraph* _tmp77_ = NULL;
	BoxesMiniGraph* _tmp78_ = NULL;
	BoxesMiniGraph* _tmp79_ = NULL;
	const gchar* _tmp80_ = NULL;
	GtkLabel* _tmp81_ = NULL;
	GtkLabel* _tmp82_ = NULL;
	GtkStyleContext* _tmp83_ = NULL;
	GtkLabel* _tmp84_ = NULL;
	gdouble* _tmp85_ = NULL;
	gdouble* _tmp86_ = NULL;
	gint _tmp86__length1 = 0;
	BoxesMiniGraph* _tmp87_ = NULL;
	BoxesMiniGraph* _tmp88_ = NULL;
	BoxesMiniGraph* _tmp89_ = NULL;
	const gchar* _tmp90_ = NULL;
	GtkLabel* _tmp91_ = NULL;
	GtkLabel* _tmp92_ = NULL;
	GtkStyleContext* _tmp93_ = NULL;
	GtkLabel* _tmp94_ = NULL;
	gdouble* _tmp95_ = NULL;
	gdouble* _tmp96_ = NULL;
	gint _tmp96__length1 = 0;
	BoxesMiniGraph* _tmp97_ = NULL;
	BoxesMiniGraph* _tmp98_ = NULL;
	BoxesMiniGraph* _tmp99_ = NULL;
	const gchar* _tmp100_ = NULL;
	GtkButton* _tmp101_ = NULL;
	GtkButton* _tmp102_ = NULL;
	GtkButton* _tmp103_ = NULL;
	GtkNotebook* _tmp104_ = NULL;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (self != NULL);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = (GtkNotebook*) gtk_notebook_new ();
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_ref_sink (_tmp0_);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->notebook);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->notebook = _tmp0_;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp1_ = self->priv->notebook;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_notebook_set_show_tabs (_tmp1_, FALSE);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp2_ = self->priv->notebook;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp3_ = gtk_widget_get_style_context ((GtkWidget*) _tmp2_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_style_context_add_class (_tmp3_, "boxes-bg");
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp4_ = self->priv->notebook;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5_ = (GtkClutterActor*) gtk_clutter_actor_new_with_contents ((GtkWidget*) _tmp4_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_ref_sink (_tmp5_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->gtk_actor = _tmp5_;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp6_ = self->priv->gtk_actor;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp7_ = gtk_clutter_actor_get_widget (_tmp6_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp8_ = gtk_widget_get_style_context (_tmp7_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_style_context_add_class (_tmp8_, "boxes-bg");
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp9_ = self->priv->gtk_actor;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	clutter_actor_set_name ((ClutterActor*) _tmp9_, "properties");
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp10_ = self->priv->gtk_actor;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	clutter_actor_set_opacity ((ClutterActor*) _tmp10_, (guint) 0);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp11_ = self->priv->gtk_actor;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	clutter_actor_set_x_align ((ClutterActor*) _tmp11_, CLUTTER_ACTOR_ALIGN_FILL);
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp12_ = self->priv->gtk_actor;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	clutter_actor_set_y_align ((ClutterActor*) _tmp12_, CLUTTER_ACTOR_ALIGN_FILL);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp13_ = self->priv->gtk_actor;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	clutter_actor_set_x_expand ((ClutterActor*) _tmp13_, TRUE);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp14_ = self->priv->gtk_actor;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	clutter_actor_set_y_expand ((ClutterActor*) _tmp14_, TRUE);
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp15_ = boxes_app_app;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp16_ = _tmp15_->topbar;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp17_ = _tmp16_->notebook;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp18_ = gtk_notebook_get_nth_page (_tmp17_, (gint) BOXES_TOPBAR_PAGE_PROPERTIES);
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp19_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, GTK_TYPE_BOX) ? ((GtkBox*) _tmp18_) : NULL);
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	hbox = _tmp19_;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp20_ = (GtkHeaderBar*) gtk_header_bar_new ();
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_ref_sink (_tmp20_);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->toolbar);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->toolbar = _tmp20_;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp21_ = self->priv->toolbar;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp22_ = gtk_widget_get_style_context ((GtkWidget*) _tmp21_);
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_style_context_add_class (_tmp22_, GTK_STYLE_CLASS_MENUBAR);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp23_ = self->priv->toolbar;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp24_ = gtk_widget_get_style_context ((GtkWidget*) _tmp23_);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_style_context_add_class (_tmp24_, "titlebar");
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp25_ = self->priv->toolbar;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_header_bar_set_show_close_button (_tmp25_, TRUE);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp26_ = hbox;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp27_ = self->priv->toolbar;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_box_pack_start (_tmp26_, (GtkWidget*) _tmp27_, TRUE, TRUE, (guint) 0);
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp29_ = self->priv->toolbar;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp30_ = gtk_widget_get_direction ((GtkWidget*) _tmp29_);
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp30_ == GTK_TEXT_DIR_RTL) {
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp28_ = "go-previous-rtl-symbolic";
#line 1394 "properties.c"
	} else {
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp28_ = "go-previous-symbolic";
#line 1398 "properties.c"
	}
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp31_ = _tmp28_;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp32_ = g_strdup (_tmp31_);
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	back_icon = _tmp32_;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp33_ = (GtkImage*) gtk_image_new_from_icon_name (back_icon, GTK_ICON_SIZE_MENU);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_ref_sink (_tmp33_);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	back_image = _tmp33_;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp34_ = (GtkButton*) gtk_button_new ();
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_ref_sink (_tmp34_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->back);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->back = _tmp34_;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp35_ = self->priv->back;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_button_set_image (_tmp35_, (GtkWidget*) back_image);
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp36_ = self->priv->back;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp36_, GTK_ALIGN_CENTER);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp37_ = self->priv->back;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp38_ = gtk_widget_get_style_context ((GtkWidget*) _tmp37_);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_style_context_add_class (_tmp38_, "image-button");
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp39_ = self->priv->toolbar;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp40_ = self->priv->back;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_header_bar_pack_start (_tmp39_, (GtkWidget*) _tmp40_);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp41_ = self->priv->back;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_signal_connect_object (_tmp41_, "clicked", (GCallback) ___lambda150__gtk_button_clicked, self, 0);
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp42_ = hbox;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp42_);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp43_ = boxes_app_app;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp44_ = _tmp43_->sidebar;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp45_ = _tmp44_->notebook;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp46_ = gtk_notebook_get_nth_page (_tmp45_, (gint) BOXES_SIDEBAR_PAGE_PROPERTIES);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp47_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp46_, GTK_TYPE_BOX) ? ((GtkBox*) _tmp46_) : NULL);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	vbox = _tmp47_;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp48_ = (GtkTreeView*) gtk_tree_view_new ();
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_ref_sink (_tmp48_);
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->tree_view);
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->tree_view = _tmp48_;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp49_ = self->priv->tree_view;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp50_ = gtk_widget_get_style_context ((GtkWidget*) _tmp49_);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_style_context_add_class (_tmp50_, "boxes-bg");
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp51_ = self->priv->tree_view;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp52_ = gtk_tree_view_get_selection (_tmp51_);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp53_ = _g_object_ref0 (_tmp52_);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	selection = _tmp53_;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp54_ = self->priv->tree_view;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_tree_view_activate_on_single_click (_tmp54_, TRUE);
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp55_ = self->priv->tree_view;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_signal_connect_object (_tmp55_, "row-activated", (GCallback) ___lambda153__gtk_tree_view_row_activated, self, 0);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp56_ = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_BOOLEAN);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->listmodel);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->listmodel = _tmp56_;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp57_ = self->priv->listmodel;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp58_ = (GtkTreeModelFilter*) gtk_tree_model_filter_new ((GtkTreeModel*) _tmp57_, NULL);
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->model_filter);
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->model_filter = _tmp58_;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp59_ = self->priv->model_filter;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_tree_model_filter_set_visible_column (_tmp59_, 1);
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp60_ = self->priv->tree_view;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp61_ = self->priv->model_filter;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_tree_view_set_model (_tmp60_, (GtkTreeModel*) _tmp61_);
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp62_ = self->priv->tree_view;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_tree_view_set_headers_visible (_tmp62_, FALSE);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp63_ = (GtkCellRendererText*) gtk_cell_renderer_text_new ();
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_ref_sink (_tmp63_);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	renderer = _tmp63_;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_set ((GtkCellRenderer*) renderer, "xpad", (guint) 20, NULL);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_set (renderer, "weight", (gint) PANGO_WEIGHT_BOLD, NULL);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp64_ = self->priv->tree_view;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_tree_view_insert_column_with_attributes (_tmp64_, -1, "", (GtkCellRenderer*) renderer, "text", 0, NULL);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp65_ = self->priv->tree_view;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_box_pack_start (vbox, (GtkWidget*) _tmp65_, TRUE, TRUE, (guint) 0);
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp66_ = (GtkGrid*) gtk_grid_new ();
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_ref_sink (_tmp66_);
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	grid = _tmp66_;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_box_pack_start (vbox, (GtkWidget*) grid, FALSE, FALSE, (guint) 0);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_grid_set_column_homogeneous (grid, FALSE);
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_grid_set_column_spacing (grid, 2);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_grid_set_row_spacing (grid, 10);
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_set_margin_left ((GtkWidget*) grid, 10);
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_set_margin_right ((GtkWidget*) grid, 10 + BOXES_SIDEBAR_shadow_width);
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_set_margin_bottom ((GtkWidget*) grid, 30);
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_set_margin_top ((GtkWidget*) grid, 10);
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp67_ = (GtkAlignment*) gtk_alignment_new (0.0f, 0.0f, 0.0f, 0.0f);
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_ref_sink (_tmp67_);
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->screenshot_placeholder);
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->screenshot_placeholder = (GtkWidget*) _tmp67_;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp68_ = self->screenshot_placeholder;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_set_size_request (_tmp68_, 180, 130);
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp69_ = self->screenshot_placeholder;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_grid_attach (grid, _tmp69_, 0, 0, 6, 1);
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp70_ = _ ("CPU:");
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp71_ = (GtkLabel*) gtk_label_new (_tmp70_);
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_ref_sink (_tmp71_);
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	label = _tmp71_;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp72_ = label;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp73_ = gtk_widget_get_style_context ((GtkWidget*) _tmp72_);
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_style_context_add_class (_tmp73_, "boxes-graph-label");
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp74_ = label;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) _tmp74_, 0, 1, 1, 1);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp75_ = g_new0 (gdouble, 0);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp76_ = _tmp75_;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp76__length1 = 0;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp77_ = boxes_mini_graph_new_with_ymax (_tmp76_, 0, 100.0, 20);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_ref_sink (_tmp77_);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->cpu);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->cpu = _tmp77_;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp76_ = (g_free (_tmp76_), NULL);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp78_ = self->priv->cpu;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_set_hexpand ((GtkWidget*) _tmp78_, TRUE);
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp79_ = self->priv->cpu;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) _tmp79_, 1, 1, 1, 1);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp80_ = _ ("I/O:");
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp81_ = (GtkLabel*) gtk_label_new (_tmp80_);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_ref_sink (_tmp81_);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (label);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	label = _tmp81_;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp82_ = label;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp83_ = gtk_widget_get_style_context ((GtkWidget*) _tmp82_);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_style_context_add_class (_tmp83_, "boxes-graph-label");
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp84_ = label;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) _tmp84_, 2, 1, 1, 1);
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp85_ = g_new0 (gdouble, 0);
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp86_ = _tmp85_;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp86__length1 = 0;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp87_ = boxes_mini_graph_new (_tmp86_, 0, 20);
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_ref_sink (_tmp87_);
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->io);
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->io = _tmp87_;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp86_ = (g_free (_tmp86_), NULL);
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp88_ = self->priv->io;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_set_hexpand ((GtkWidget*) _tmp88_, TRUE);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp89_ = self->priv->io;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) _tmp89_, 3, 1, 1, 1);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp90_ = _ ("Net:");
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp91_ = (GtkLabel*) gtk_label_new (_tmp90_);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_ref_sink (_tmp91_);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (label);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	label = _tmp91_;
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp92_ = label;
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp93_ = gtk_widget_get_style_context ((GtkWidget*) _tmp92_);
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_style_context_add_class (_tmp93_, "boxes-graph-label");
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp94_ = label;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) _tmp94_, 4, 1, 1, 1);
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp95_ = g_new0 (gdouble, 0);
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp96_ = _tmp95_;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp96__length1 = 0;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp97_ = boxes_mini_graph_new (_tmp96_, 0, 20);
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_ref_sink (_tmp97_);
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->net);
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->net = _tmp97_;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp96_ = (g_free (_tmp96_), NULL);
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp98_ = self->priv->net;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_set_hexpand ((GtkWidget*) _tmp98_, TRUE);
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp99_ = self->priv->net;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) _tmp99_, 5, 1, 1, 1);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp100_ = _ ("Force Shutdown");
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp101_ = (GtkButton*) gtk_button_new_with_label (_tmp100_);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_ref_sink (_tmp101_);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->shutdown_button);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->shutdown_button = _tmp101_;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp102_ = self->priv->shutdown_button;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_signal_connect_object (_tmp102_, "clicked", (GCallback) ___lambda154__gtk_button_clicked, self, 0);
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp103_ = self->priv->shutdown_button;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_grid_attach (grid, (GtkWidget*) _tmp103_, 0, 2, 6, 1);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_show_all ((GtkWidget*) vbox);
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp104_ = self->priv->notebook;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp104_);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (label);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (grid);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (renderer);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (selection);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (vbox);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (back_image);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_free0 (back_icon);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (hbox);
#line 1746 "properties.c"
}


static Block50Data* block50_data_ref (Block50Data* _data50_) {
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_atomic_int_inc (&_data50_->_ref_count_);
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return _data50_;
#line 1755 "properties.c"
}


static void block50_data_unref (void * _userdata_) {
	Block50Data* _data50_;
	_data50_ = (Block50Data*) _userdata_;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (g_atomic_int_dec_and_test (&_data50_->_ref_count_)) {
#line 1764 "properties.c"
		BoxesProperties * self;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		self = _data50_->self;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (_data50_->libvirt_machine);
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (self);
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_slice_free (Block50Data, _data50_);
#line 1774 "properties.c"
	}
}


static void ____lambda157_ (Block50Data* _data50_) {
	BoxesProperties * self;
	BoxesMiniGraph* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	gdouble* _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
	BoxesMiniGraph* _tmp3_ = NULL;
	BoxesLibvirtMachine* _tmp4_ = NULL;
	gdouble* _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
	BoxesMiniGraph* _tmp6_ = NULL;
	BoxesLibvirtMachine* _tmp7_ = NULL;
	gdouble* _tmp8_ = NULL;
	gint _tmp8__length1 = 0;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = _data50_->self;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->cpu;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp1_ = _data50_->libvirt_machine;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp2_ = _tmp1_->cpu_stats;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp2__length1 = _tmp1_->cpu_stats_length1;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_mini_graph_set_points (_tmp0_, _tmp2_, _tmp2__length1);
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp3_ = self->priv->net;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp4_ = _data50_->libvirt_machine;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5_ = _tmp4_->net_stats;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5__length1 = _tmp4_->net_stats_length1;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_mini_graph_set_points (_tmp3_, _tmp5_, _tmp5__length1);
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp6_ = self->priv->io;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp7_ = _data50_->libvirt_machine;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp8_ = _tmp7_->io_stats;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp8__length1 = _tmp7_->io_stats_length1;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_mini_graph_set_points (_tmp6_, _tmp8_, _tmp8__length1);
#line 1825 "properties.c"
}


static void _____lambda157__boxes_libvirt_machine_stats_updated (BoxesLibvirtMachine* _sender, gpointer self) {
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	____lambda157_ (self);
#line 1832 "properties.c"
}


static void boxes_properties_real_ui_state_changed (BoxesUI* base) {
	BoxesProperties * self;
	gulong _tmp0_ = 0UL;
	BoxesUIState _tmp4_ = 0;
	BoxesUIState _tmp5_ = 0;
	gint _tmp43_ = 0;
	BoxesUIState _tmp44_ = 0;
	BoxesUIState _tmp45_ = 0;
	ClutterActor* _tmp46_ = NULL;
	ClutterActor* _tmp47_ = NULL;
	gint _tmp48_ = 0;
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesProperties*) base;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->stats_id;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp0_ != ((gulong) 0)) {
#line 1853 "properties.c"
		BoxesApp* _tmp1_ = NULL;
		BoxesCollectionItem* _tmp2_ = NULL;
		gulong _tmp3_ = 0UL;
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp1_ = boxes_app_app;
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp2_ = _tmp1_->current_item;
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp3_ = self->priv->stats_id;
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_signal_handler_disconnect ((GObject*) _tmp2_, _tmp3_);
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		self->priv->stats_id = (gulong) 0;
#line 1867 "properties.c"
	}
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp4_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5_ = _tmp4_;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp5_ == BOXES_UI_STATE_PROPERTIES) {
#line 1875 "properties.c"
		gboolean _tmp6_ = FALSE;
		BoxesUIState _tmp7_ = 0;
		BoxesUIState _tmp8_ = 0;
		gboolean _tmp12_ = FALSE;
		BoxesApp* _tmp13_ = NULL;
		BoxesApp* _tmp14_ = NULL;
		BoxesCollectionItem* _tmp15_ = NULL;
		BoxesApp* _tmp21_ = NULL;
		BoxesCollectionItem* _tmp22_ = NULL;
		GBinding* _tmp23_ = NULL;
		GBinding* _tmp24_ = NULL;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp7_ = boxes_ui_get_previous_ui_state ((BoxesUI*) self);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp8_ = _tmp7_;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		if (_tmp8_ == BOXES_UI_STATE_DISPLAY) {
#line 1893 "properties.c"
			BoxesApp* _tmp9_ = NULL;
			gboolean _tmp10_ = FALSE;
			gboolean _tmp11_ = FALSE;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp9_ = boxes_app_app;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp10_ = boxes_app_get_fullscreen (_tmp9_);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp11_ = _tmp10_;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp6_ = _tmp11_;
#line 1905 "properties.c"
		} else {
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp6_ = FALSE;
#line 1909 "properties.c"
		}
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp12_ = _tmp6_;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		self->priv->restore_fullscreen = _tmp12_;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp13_ = boxes_app_app;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		boxes_app_set_fullscreen (_tmp13_, FALSE);
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp14_ = boxes_app_app;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp15_ = _tmp14_->current_item;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, BOXES_TYPE_LIBVIRT_MACHINE)) {
#line 1925 "properties.c"
			Block50Data* _data50_;
			BoxesApp* _tmp16_ = NULL;
			BoxesCollectionItem* _tmp17_ = NULL;
			BoxesLibvirtMachine* _tmp18_ = NULL;
			BoxesLibvirtMachine* _tmp19_ = NULL;
			gulong _tmp20_ = 0UL;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data50_ = g_slice_new0 (Block50Data);
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data50_->_ref_count_ = 1;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data50_->self = g_object_ref (self);
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp16_ = boxes_app_app;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp17_ = _tmp16_->current_item;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp18_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp17_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp17_) : NULL);
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data50_->libvirt_machine = _tmp18_;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp19_ = _data50_->libvirt_machine;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp20_ = g_signal_connect_data (_tmp19_, "stats-updated", (GCallback) _____lambda157__boxes_libvirt_machine_stats_updated, block50_data_ref (_data50_), (GClosureNotify) block50_data_unref, 0);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			self->priv->stats_id = _tmp20_;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			block50_data_unref (_data50_);
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_data50_ = NULL;
#line 1956 "properties.c"
		}
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		boxes_properties_populate (self);
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp21_ = boxes_app_app;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp22_ = _tmp21_->current_item;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp23_ = g_object_bind_property_with_closures ((GObject*) _tmp22_, "name", (GObject*) self, "title", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp24_ = _g_object_ref0 (_tmp23_);
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_g_object_unref0 (self->priv->toolbar_label_bind);
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		self->priv->toolbar_label_bind = _tmp24_;
#line 1972 "properties.c"
	} else {
		BoxesUIState _tmp25_ = 0;
		BoxesUIState _tmp26_ = 0;
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp25_ = boxes_ui_get_previous_ui_state ((BoxesUI*) self);
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp26_ = _tmp25_;
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		if (_tmp26_ == BOXES_UI_STATE_PROPERTIES) {
#line 1982 "properties.c"
			gboolean _tmp41_ = FALSE;
			{
				gint i = 0;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				i = 0;
#line 1988 "properties.c"
				{
					gboolean _tmp27_ = FALSE;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp27_ = TRUE;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					while (TRUE) {
#line 1995 "properties.c"
						gboolean _tmp28_ = FALSE;
						gint _tmp30_ = 0;
						BoxesPropertiesPageWidget* page = NULL;
						GtkNotebook* _tmp31_ = NULL;
						gint _tmp32_ = 0;
						gchar* _tmp33_ = NULL;
						gchar* _tmp34_ = NULL;
						gchar* _tmp35_ = NULL;
						gchar* _tmp36_ = NULL;
						gconstpointer _tmp37_ = NULL;
						BoxesPropertiesPageWidget* _tmp38_ = NULL;
						BoxesPropertiesPageWidget* _tmp39_ = NULL;
						BoxesPropertiesPageWidget* _tmp40_ = NULL;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp28_ = _tmp27_;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						if (!_tmp28_) {
#line 2013 "properties.c"
							gint _tmp29_ = 0;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
							_tmp29_ = i;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
							i = _tmp29_ + 1;
#line 2019 "properties.c"
						}
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp27_ = FALSE;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp30_ = i;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						if (!(_tmp30_ < ((gint) BOXES_PROPERTIES_PAGE_LAST))) {
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
							break;
#line 2029 "properties.c"
						}
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp31_ = self->priv->notebook;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp32_ = i;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp33_ = g_strdup_printf ("%i", _tmp32_);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp34_ = _tmp33_;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp35_ = g_strconcat ("boxes-property-", _tmp34_, NULL);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp36_ = _tmp35_;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp37_ = g_object_get_data ((GObject*) _tmp31_, _tmp36_);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp38_ = _g_object_ref0 ((BoxesPropertiesPageWidget*) _tmp37_);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp39_ = _tmp38_;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_g_free0 (_tmp36_);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_g_free0 (_tmp34_);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						page = _tmp39_;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp40_ = page;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						boxes_properties_page_widget_flush_changes (_tmp40_);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_g_object_unref0 (page);
#line 2061 "properties.c"
					}
				}
			}
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp41_ = self->priv->restore_fullscreen;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			if (_tmp41_) {
#line 2069 "properties.c"
				BoxesApp* _tmp42_ = NULL;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp42_ = boxes_app_app;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				boxes_app_set_fullscreen (_tmp42_, TRUE);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				self->priv->restore_fullscreen = FALSE;
#line 2077 "properties.c"
			}
		}
	}
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp44_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp45_ = _tmp44_;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (_tmp45_ == BOXES_UI_STATE_PROPERTIES) {
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp43_ = 255;
#line 2089 "properties.c"
	} else {
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp43_ = 0;
#line 2093 "properties.c"
	}
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp46_ = boxes_ui_get_actor ((BoxesUI*) self);
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp47_ = _tmp46_;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp48_ = _tmp43_;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_fade_actor (_tmp47_, (guint) _tmp48_);
#line 2103 "properties.c"
}


static ClutterActor* boxes_properties_real_get_actor (BoxesUI* base) {
	ClutterActor* result;
	BoxesProperties* self;
	GtkClutterActor* _tmp0_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesProperties*) base;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->gtk_actor;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	result = (ClutterActor*) _tmp0_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return result;
#line 2119 "properties.c"
}


void boxes_properties_set_title (BoxesProperties* self, const gchar* value) {
	GtkHeaderBar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	BoxesApp* _tmp2_ = NULL;
	BoxesCollectionItem* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (self != NULL);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->toolbar;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp1_ = _ ("%s - Properties");
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp2_ = boxes_app_app;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp3_ = _tmp2_->current_item;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp4_ = boxes_collection_item_get_name (_tmp3_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5_ = _tmp4_;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp6_ = g_strdup_printf (_tmp1_, _tmp5_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp7_ = _tmp6_;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_header_bar_set_title (_tmp0_, _tmp7_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_free0 (_tmp7_);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_notify ((GObject *) self, "title");
#line 2156 "properties.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 2163 "properties.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_list_free (self);
#line 2172 "properties.c"
}


static void boxes_properties_page_widget_update_infobar (BoxesPropertiesPageWidget* self) {
	gboolean show_it = FALSE;
	GList* _tmp0_ = NULL;
	GtkInfoBar* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (self != NULL);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	show_it = FALSE;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->properties;
#line 2187 "properties.c"
	{
		GList* property_collection = NULL;
		GList* property_it = NULL;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		property_collection = _tmp0_;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		for (property_it = property_collection; property_it != NULL; property_it = property_it->next) {
#line 2195 "properties.c"
			BoxesProperty* _tmp1_ = NULL;
			BoxesProperty* property = NULL;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp1_ = _g_object_ref0 ((BoxesProperty*) property_it->data);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			property = _tmp1_;
#line 2202 "properties.c"
			{
				BoxesProperty* _tmp2_ = NULL;
				gboolean _tmp3_ = FALSE;
				gboolean _tmp4_ = FALSE;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp2_ = property;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp3_ = boxes_property_get_reboot_required (_tmp2_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp4_ = _tmp3_;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				if (_tmp4_) {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					show_it = TRUE;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_g_object_unref0 (property);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					break;
#line 2221 "properties.c"
				}
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_object_unref0 (property);
#line 2225 "properties.c"
			}
		}
	}
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp5_ = self->priv->infobar;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp6_ = show_it;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp5_, _tmp6_);
#line 2235 "properties.c"
}


static void _boxes_properties_page_widget_update_infobar_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_properties_page_widget_update_infobar (self);
#line 2242 "properties.c"
}


static void _____lambda155_ (BoxesPropertiesPageWidget* self) {
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_signal_emit_by_name (self, "refresh-properties");
#line 2249 "properties.c"
}


static void ______lambda155__boxes_property_refresh_properties (BoxesProperty* _sender, gpointer self) {
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_____lambda155_ (self);
#line 2256 "properties.c"
}


static BoxesPropertiesPageWidget* boxes_properties_page_widget_construct (GType object_type, BoxesPropertiesPage page, BoxesMachine* machine) {
	BoxesPropertiesPageWidget * self = NULL;
	BoxesPropertiesPage _tmp0_ = 0;
	GtkGrid* _tmp9_ = NULL;
	GtkGrid* _tmp10_ = NULL;
	GtkGrid* _tmp11_ = NULL;
	GtkGrid* _tmp12_ = NULL;
	GtkGrid* _tmp13_ = NULL;
	GtkInfoBar* _tmp14_ = NULL;
	GtkInfoBar* _tmp15_ = NULL;
	GtkContainer* infobar_container = NULL;
	GtkInfoBar* _tmp16_ = NULL;
	GtkContainer* _tmp17_ = NULL;
	GtkContainer* _tmp18_ = NULL;
	GtkLabel* label = NULL;
	const gchar* _tmp19_ = NULL;
	GtkLabel* _tmp20_ = NULL;
	GtkLabel* _tmp21_ = NULL;
	GtkContainer* _tmp22_ = NULL;
	GtkLabel* _tmp23_ = NULL;
	GtkInfoBar* _tmp24_ = NULL;
	GtkInfoBar* _tmp25_ = NULL;
	GtkGrid* _tmp26_ = NULL;
	GtkInfoBar* _tmp27_ = NULL;
	PropertyCreationFlag flags = 0;
	BoxesMachine* _tmp28_ = NULL;
	BoxesPropertiesPage _tmp29_ = 0;
	GList* _tmp30_ = NULL;
	GList* _tmp31_ = NULL;
	guint _tmp32_ = 0U;
	gboolean _tmp33_ = FALSE;
	GtkGrid* _tmp82_ = NULL;
	GtkGrid* _tmp83_ = NULL;
	GtkWidget* _tmp84_ = NULL;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = (BoxesPropertiesPageWidget*) g_object_new (object_type, NULL);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = page;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	switch (_tmp0_) {
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_PAGE_LOGIN:
#line 2304 "properties.c"
		{
			const gchar* _tmp1_ = NULL;
			gchar* _tmp2_ = NULL;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp1_ = _ ("Login");
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp2_ = g_strdup (_tmp1_);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_g_free0 (self->name);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			self->name = _tmp2_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			break;
#line 2318 "properties.c"
		}
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_PAGE_SYSTEM:
#line 2322 "properties.c"
		{
			const gchar* _tmp3_ = NULL;
			gchar* _tmp4_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp3_ = _ ("System");
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp4_ = g_strdup (_tmp3_);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_g_free0 (self->name);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			self->name = _tmp4_;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			break;
#line 2336 "properties.c"
		}
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_PAGE_DISPLAY:
#line 2340 "properties.c"
		{
			const gchar* _tmp5_ = NULL;
			gchar* _tmp6_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp5_ = _ ("Display");
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp6_ = g_strdup (_tmp5_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_g_free0 (self->name);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			self->name = _tmp6_;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			break;
#line 2354 "properties.c"
		}
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_PAGE_DEVICES:
#line 2358 "properties.c"
		{
			const gchar* _tmp7_ = NULL;
			gchar* _tmp8_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp7_ = _ ("Devices");
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp8_ = g_strdup (_tmp7_);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_g_free0 (self->name);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			self->name = _tmp8_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			break;
#line 2372 "properties.c"
		}
		default:
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 2377 "properties.c"
	}
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp9_ = (GtkGrid*) gtk_grid_new ();
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_ref_sink (_tmp9_);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->grid);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->grid = _tmp9_;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp10_ = self->priv->grid;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_set ((GtkWidget*) _tmp10_, "margin", 20, NULL);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp11_ = self->priv->grid;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_grid_set_row_spacing (_tmp11_, 10);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp12_ = self->priv->grid;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_grid_set_column_spacing (_tmp12_, 20);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp13_ = self->priv->grid;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp13_, GTK_ALIGN_START);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp14_ = (GtkInfoBar*) gtk_info_bar_new ();
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_ref_sink (_tmp14_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->infobar);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->infobar = _tmp14_;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp15_ = self->priv->infobar;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_set_no_show_all ((GtkWidget*) _tmp15_, TRUE);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp16_ = self->priv->infobar;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp17_ = gtk_info_bar_get_content_area (_tmp16_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp18_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp17_, GTK_TYPE_CONTAINER) ? ((GtkContainer*) _tmp17_) : NULL);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	infobar_container = _tmp18_;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp19_ = _ ("Some changes may take effect only after reboot");
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp20_ = (GtkLabel*) gtk_label_new (_tmp19_);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_ref_sink (_tmp20_);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	label = _tmp20_;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp21_ = label;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp21_, TRUE);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp22_ = infobar_container;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp23_ = label;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_container_add (_tmp22_, (GtkWidget*) _tmp23_);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp24_ = self->priv->infobar;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_info_bar_set_message_type (_tmp24_, GTK_MESSAGE_INFO);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp25_ = self->priv->infobar;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_set_hexpand ((GtkWidget*) _tmp25_, TRUE);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp26_ = self->priv->grid;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp27_ = self->priv->infobar;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_grid_attach (_tmp26_, (GtkWidget*) _tmp27_, 0, 0, 2, 1);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	flags = PROPERTY_CREATION_FLAG_NONE;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp28_ = machine;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp29_ = page;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp30_ = boxes_machine_get_properties (_tmp28_, _tmp29_, &flags);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	__g_list_free__g_object_unref0_0 (self->priv->properties);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv->properties = _tmp30_;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp31_ = self->priv->properties;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp32_ = g_list_length (_tmp31_);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->empty = _tmp32_ == ((guint) 0);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp33_ = self->empty;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	if (!_tmp33_) {
#line 2477 "properties.c"
		gint current_row = 0;
		GList* _tmp34_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		current_row = 1;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		_tmp34_ = self->priv->properties;
#line 2484 "properties.c"
		{
			GList* property_collection = NULL;
			GList* property_it = NULL;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			property_collection = _tmp34_;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			for (property_it = property_collection; property_it != NULL; property_it = property_it->next) {
#line 2492 "properties.c"
				BoxesProperty* _tmp35_ = NULL;
				BoxesProperty* property = NULL;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp35_ = _g_object_ref0 ((BoxesProperty*) property_it->data);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				property = _tmp35_;
#line 2499 "properties.c"
				{
					BoxesProperty* _tmp36_ = NULL;
					const gchar* _tmp37_ = NULL;
					const gchar* _tmp38_ = NULL;
					BoxesProperty* _tmp68_ = NULL;
					GtkWidget* _tmp69_ = NULL;
					GtkWidget* _tmp70_ = NULL;
					GtkWidget* _tmp71_ = NULL;
					GtkWidget* _tmp72_ = NULL;
					BoxesProperty* _tmp79_ = NULL;
					BoxesProperty* _tmp80_ = NULL;
					gint _tmp81_ = 0;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp36_ = property;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp37_ = boxes_property_get_description (_tmp36_);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp38_ = _tmp37_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					if (_tmp38_ != NULL) {
#line 2520 "properties.c"
						GtkLabel* label_name = NULL;
						BoxesProperty* _tmp39_ = NULL;
						const gchar* _tmp40_ = NULL;
						const gchar* _tmp41_ = NULL;
						GtkLabel* _tmp42_ = NULL;
						GtkLabel* _tmp43_ = NULL;
						GtkStyleContext* _tmp44_ = NULL;
						GtkLabel* _tmp45_ = NULL;
						GtkLabel* _tmp46_ = NULL;
						GtkLabel* _tmp47_ = NULL;
						GtkGrid* _tmp48_ = NULL;
						GtkLabel* _tmp49_ = NULL;
						gint _tmp50_ = 0;
						GtkWidget* widget = NULL;
						BoxesProperty* _tmp51_ = NULL;
						GtkWidget* _tmp52_ = NULL;
						GtkWidget* _tmp53_ = NULL;
						GtkWidget* _tmp54_ = NULL;
						GtkWidget* _tmp55_ = NULL;
						GtkGrid* _tmp56_ = NULL;
						GtkWidget* _tmp57_ = NULL;
						gint _tmp58_ = 0;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp39_ = property;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp40_ = boxes_property_get_description (_tmp39_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp41_ = _tmp40_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp42_ = (GtkLabel*) gtk_label_new (_tmp41_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						g_object_ref_sink (_tmp42_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						label_name = _tmp42_;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp43_ = label_name;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp44_ = gtk_widget_get_style_context ((GtkWidget*) _tmp43_);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_style_context_add_class (_tmp44_, "boxes-property-name-label");
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp45_ = label_name;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_margin_left ((GtkWidget*) _tmp45_, 25);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp46_ = label_name;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_halign ((GtkWidget*) _tmp46_, GTK_ALIGN_START);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp47_ = label_name;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_hexpand ((GtkWidget*) _tmp47_, FALSE);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp48_ = self->priv->grid;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp49_ = label_name;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp50_ = current_row;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_grid_attach (_tmp48_, (GtkWidget*) _tmp49_, 0, _tmp50_, 1, 1);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp51_ = property;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp52_ = boxes_property_get_widget (_tmp51_);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp53_ = _tmp52_;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp54_ = _g_object_ref0 (_tmp53_);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						widget = _tmp54_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp55_ = widget;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_hexpand (_tmp55_, TRUE);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp56_ = self->priv->grid;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp57_ = widget;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp58_ = current_row;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_grid_attach (_tmp56_, _tmp57_, 1, _tmp58_, 1, 1);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_g_object_unref0 (widget);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_g_object_unref0 (label_name);
#line 2607 "properties.c"
					} else {
						GtkWidget* widget = NULL;
						BoxesProperty* _tmp59_ = NULL;
						GtkWidget* _tmp60_ = NULL;
						GtkWidget* _tmp61_ = NULL;
						GtkWidget* _tmp62_ = NULL;
						GtkWidget* _tmp63_ = NULL;
						GtkWidget* _tmp64_ = NULL;
						GtkGrid* _tmp65_ = NULL;
						GtkWidget* _tmp66_ = NULL;
						gint _tmp67_ = 0;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp59_ = property;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp60_ = boxes_property_get_widget (_tmp59_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp61_ = _tmp60_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp62_ = _g_object_ref0 (_tmp61_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						widget = _tmp62_;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp63_ = widget;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_hexpand (_tmp63_, TRUE);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp64_ = widget;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_margin_left (_tmp64_, 25);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp65_ = self->priv->grid;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp66_ = widget;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp67_ = current_row;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_grid_attach (_tmp65_, _tmp66_, 0, _tmp67_, 2, 1);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_g_object_unref0 (widget);
#line 2647 "properties.c"
					}
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp68_ = property;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp69_ = boxes_property_get_extra_widget (_tmp68_);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp70_ = _tmp69_;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp71_ = _g_object_ref0 (_tmp70_);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_g_object_unref0 (self->widget);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					self->widget = _tmp71_;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp72_ = self->widget;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					if (_tmp72_ != NULL) {
#line 2665 "properties.c"
						gint _tmp73_ = 0;
						GtkWidget* _tmp74_ = NULL;
						GtkWidget* _tmp75_ = NULL;
						GtkGrid* _tmp76_ = NULL;
						GtkWidget* _tmp77_ = NULL;
						gint _tmp78_ = 0;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp73_ = current_row;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						current_row = _tmp73_ + 1;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp74_ = self->widget;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_margin_left (_tmp74_, 25);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp75_ = self->widget;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_widget_set_hexpand (_tmp75_, TRUE);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp76_ = self->priv->grid;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp77_ = self->widget;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						_tmp78_ = current_row;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
						gtk_grid_attach (_tmp76_, _tmp77_, 0, _tmp78_, 2, 1);
#line 2692 "properties.c"
					}
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp79_ = property;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					g_signal_connect_object ((GObject*) _tmp79_, "notify::reboot-required", (GCallback) _boxes_properties_page_widget_update_infobar_g_object_notify, self, 0);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp80_ = property;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					g_signal_connect_object (_tmp80_, "refresh-properties", (GCallback) ______lambda155__boxes_property_refresh_properties, self, 0);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_tmp81_ = current_row;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					current_row = _tmp81_ + 1;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
					_g_object_unref0 (property);
#line 2708 "properties.c"
				}
			}
		}
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		boxes_properties_page_widget_update_infobar (self);
#line 2714 "properties.c"
	}
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp82_ = self->priv->grid;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp82_);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp83_ = self->priv->grid;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp84_ = _g_object_ref0 ((GtkWidget*) _tmp83_);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->widget);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->widget = _tmp84_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (label);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (infobar_container);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return self;
#line 2734 "properties.c"
}


static BoxesPropertiesPageWidget* boxes_properties_page_widget_new (BoxesPropertiesPage page, BoxesMachine* machine) {
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	return boxes_properties_page_widget_construct (BOXES_PROPERTIES_TYPE_PAGE_WIDGET, page, machine);
#line 2741 "properties.c"
}


static void boxes_properties_page_widget_flush_changes (BoxesPropertiesPageWidget* self) {
	GList* _tmp0_ = NULL;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_return_if_fail (self != NULL);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->properties;
#line 2751 "properties.c"
	{
		GList* property_collection = NULL;
		GList* property_it = NULL;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		property_collection = _tmp0_;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		for (property_it = property_collection; property_it != NULL; property_it = property_it->next) {
#line 2759 "properties.c"
			BoxesProperty* _tmp1_ = NULL;
			BoxesProperty* property = NULL;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp1_ = _g_object_ref0 ((BoxesProperty*) property_it->data);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			property = _tmp1_;
#line 2766 "properties.c"
			{
				BoxesProperty* _tmp2_ = NULL;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp2_ = property;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				boxes_property_flush (_tmp2_);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_object_unref0 (property);
#line 2775 "properties.c"
			}
		}
	}
}


static void boxes_properties_page_widget_class_init (BoxesPropertiesPageWidgetClass * klass) {
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_properties_page_widget_parent_class = g_type_class_peek_parent (klass);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_type_class_add_private (klass, sizeof (BoxesPropertiesPageWidgetPrivate));
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_properties_page_widget_finalize;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_signal_new ("refresh_properties", BOXES_PROPERTIES_TYPE_PAGE_WIDGET, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 2791 "properties.c"
}


static void boxes_properties_page_widget_instance_init (BoxesPropertiesPageWidget * self) {
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv = BOXES_PROPERTIES_PAGE_WIDGET_GET_PRIVATE (self);
#line 2798 "properties.c"
}


static void boxes_properties_page_widget_finalize (GObject* obj) {
	BoxesPropertiesPageWidget * self;
	GList* _tmp0_ = NULL;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_PROPERTIES_TYPE_PAGE_WIDGET, BoxesPropertiesPageWidget);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_tmp0_ = self->priv->properties;
#line 2809 "properties.c"
	{
		GList* property_collection = NULL;
		GList* property_it = NULL;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		property_collection = _tmp0_;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		for (property_it = property_collection; property_it != NULL; property_it = property_it->next) {
#line 2817 "properties.c"
			BoxesProperty* _tmp1_ = NULL;
			BoxesProperty* property = NULL;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			_tmp1_ = _g_object_ref0 ((BoxesProperty*) property_it->data);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
			property = _tmp1_;
#line 2824 "properties.c"
			{
				BoxesProperty* _tmp2_ = NULL;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_tmp2_ = property;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				g_signal_handlers_disconnect_by_func (_tmp2_, (void*) boxes_properties_page_widget_update_infobar, self);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
				_g_object_unref0 (property);
#line 2833 "properties.c"
			}
		}
	}
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->widget);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_free0 (self->name);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->grid);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->infobar);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	__g_list_free__g_object_unref0_0 (self->priv->properties);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (boxes_properties_page_widget_parent_class)->finalize (obj);
#line 2849 "properties.c"
}


static GType boxes_properties_page_widget_get_type (void) {
	static volatile gsize boxes_properties_page_widget_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_properties_page_widget_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesPropertiesPageWidgetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_properties_page_widget_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesPropertiesPageWidget), 0, (GInstanceInitFunc) boxes_properties_page_widget_instance_init, NULL };
		GType boxes_properties_page_widget_type_id;
		boxes_properties_page_widget_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesPropertiesPageWidget", &g_define_type_info, 0);
		g_once_init_leave (&boxes_properties_page_widget_type_id__volatile, boxes_properties_page_widget_type_id);
	}
	return boxes_properties_page_widget_type_id__volatile;
}


static void boxes_properties_class_init (BoxesPropertiesClass * klass) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	boxes_properties_parent_class = g_type_class_peek_parent (klass);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_type_class_add_private (klass, sizeof (BoxesPropertiesPrivate));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	BOXES_UI_CLASS (klass)->ui_state_changed = boxes_properties_real_ui_state_changed;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	BOXES_UI_CLASS (klass)->get_actor = boxes_properties_real_get_actor;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_properties_get_property;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_properties_set_property;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_properties_finalize;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_PROPERTIES_ACTOR, g_param_spec_object ("actor", "actor", "actor", clutter_actor_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_PROPERTIES_TITLE, g_param_spec_string ("title", "title", "title", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
#line 2884 "properties.c"
}


static void boxes_properties_instance_init (BoxesProperties * self) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self->priv = BOXES_PROPERTIES_GET_PRIVATE (self);
#line 2891 "properties.c"
}


static void boxes_properties_finalize (GObject* obj) {
	BoxesProperties * self;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_PROPERTIES, BoxesProperties);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->screenshot_placeholder);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->notebook);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->back);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->toolbar);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->listmodel);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->model_filter);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->tree_view);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->shutdown_button);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->toolbar_label_bind);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->cpu);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->io);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	_g_object_unref0 (self->priv->net);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	G_OBJECT_CLASS (boxes_properties_parent_class)->finalize (obj);
#line 2927 "properties.c"
}


GType boxes_properties_get_type (void) {
	static volatile gsize boxes_properties_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_properties_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesPropertiesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_properties_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesProperties), 0, (GInstanceInitFunc) boxes_properties_instance_init, NULL };
		GType boxes_properties_type_id;
		boxes_properties_type_id = g_type_register_static (BOXES_TYPE_UI, "BoxesProperties", &g_define_type_info, 0);
		g_once_init_leave (&boxes_properties_type_id__volatile, boxes_properties_type_id);
	}
	return boxes_properties_type_id__volatile;
}


static void _vala_boxes_properties_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesProperties * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_PROPERTIES, BoxesProperties);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	switch (property_id) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_ACTOR:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		g_value_set_object (value, boxes_ui_get_actor ((BoxesUI*) self));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 2954 "properties.c"
		default:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 2960 "properties.c"
	}
}


static void _vala_boxes_properties_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesProperties * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_PROPERTIES, BoxesProperties);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
	switch (property_id) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		case BOXES_PROPERTIES_TITLE:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		boxes_properties_set_title (self, g_value_get_string (value));
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 2976 "properties.c"
		default:
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties.vala"
		break;
#line 2982 "properties.c"
	}
}



